#!/usr/bin/env bash
# Wed 17 Aug 2016 13:50:29 CEST

set -e

if [ "${#}" != 3 ]; then
  echo "usage: `basename $0` <basedir> <name> <python-version>"
  echo "example: `basename $0` /opt/conda bob-devel-py34 3.4"
  exit 1
fi

BASEDIR=$1
NAME=$2
PYTHON_VERSION=$3
CONDA=${BASEDIR}/bin/conda

if [ -d ${BASEDIR}/envs/${NAME} ]; then
  ${CONDA} remove -n ${NAME} --all --yes
  if [ -d ${BASEDIR}/envs/${NAME} ]; then
    echo "[>>] Environment ${NAME} survived remove, brute force removing..."
    rm -rf ${BASEDIR}/envs/${NAME}
  fi
fi


if [ "$(uname)" == "Linux" ] && [ ${PYTHON_VERSION} == "2.7" ]; then
    CAFFE=caffe
else
    CAFFE=
fi

# For a complete list of dependencies, please read:
# https://gitlab.idiap.ch/bob/bob/wikis/Dependencies
echo "[>>] Creating environment ${NAME} for python ${PYTHON_VERSION} with bob dependencies..."
${CONDA} create --yes -n ${NAME} --override-channels -c conda-forge -c defaults python=$PYTHON_VERSION \
  boost \
  cmake \
  coverage \
  cython \
  dask \
  docopt \
  ffmpeg \
  gcc \
  giflib \
  hdf5 \
  ipdb \
  ipython \
  jpeg \
  libblitz \
  libmatio \
  libpng \
  libsvm \
  libtiff \
  matplotlib=1 \
  nose \
  numexpr \
  numpy \
  opencv=3 \
  pillow \
  pip \
  pkg-config \
  psutil \
  scikit-image \
  scikit-learn \
  scipy \
  sox \
  sphinx \
  sphinx_rtd_theme \
  sqlalchemy \
  tensorflow \
  virtualenv \
  vlfeat \
  ${CAFFE}

echo "[>>] Pip-installing extra dependencies in environment ${NAME} for ${PYTHON_VERSION}..."
source ${BASEDIR}/bin/activate ${NAME}

# Cyvlfeat requires special instructions
cyvlfeat=git+https://github.com/menpo/cyvlfeat@v0.4.5
if [ "$(uname)" == "Linux" ]; then
  CFLAGS="-I${CONDA_PREFIX}/include" LDFLAGS="-L${CONDA_PREFIX}/lib -lvl -Wl,-rpath=${CONDA_PREFIX}/lib" pip --no-cache-dir install ${cyvlfeat}
else
  CFLAGS="-I${CONDA_PREFIX}/include -mmacosx-version-min=10.9" LDFLAGS="-L${CONDA_PREFIX}/lib -lvl -Wl,-headerpad_max_install_names" pip --no-cache-dir install ${cyvlfeat}
fi

pip --no-cache-dir install \
  git+https://github.com/menpo/menpo@v0.7.5 \
  git+https://github.com/menpo/menpofit@v0.4.1 \
  schema \
  pyedflib \
  mne

echo "[>>] Bye!"
exit 0
